@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 
-from django.conf.urls import url, patterns
+from django.conf.urls import patterns, url
 
 from . import views
 
 
 urlpatterns = patterns(
     '',
-    url(r'^lists_of_speakers/$',
+    url(r'^csv_export_lists_of_speakers/$',
         views.CSVExportView.as_view(),
         name='csv_export_list_of_speakers'))
